#[non_exhaustive]pub struct DeletePreparedStatementInput {
pub statement_name: Option<String>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.statement_name: Option<String>The name of the prepared statement to delete.
work_group: Option<String>The workgroup to which the statement to be deleted belongs.
Implementations
Sourceimpl DeletePreparedStatementInput
impl DeletePreparedStatementInput
Sourcepub fn statement_name(&self) -> Option<&str>
pub fn statement_name(&self) -> Option<&str>
The name of the prepared statement to delete.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The workgroup to which the statement to be deleted belongs.
Sourceimpl DeletePreparedStatementInput
impl DeletePreparedStatementInput
Sourcepub fn builder() -> DeletePreparedStatementInputBuilder
pub fn builder() -> DeletePreparedStatementInputBuilder
Creates a new builder-style object to manufacture DeletePreparedStatementInput.